package com.goldenwater.slaj.hidd.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.hidd.mapper.BisHiddConsultMapper;
import com.goldenwater.slaj.hidd.domain.BisHiddConsult;
import com.goldenwater.slaj.hidd.service.IBisHiddConsultService;

/**
 * 隐患会商信息Service实现
 */
@Service
public class BisHiddConsultServiceImpl implements IBisHiddConsultService {
    @Autowired
    private BisHiddConsultMapper bisHiddConsultMapper;

    @Override
    public List<BisHiddConsult> selectBisHiddConsultList(BisHiddConsult bisHiddConsult) {
        return bisHiddConsultMapper.selectBisHiddConsultList(bisHiddConsult);
    }

    @Override
    public BisHiddConsult selectBisHiddConsultByGuid(String guid) {
        return bisHiddConsultMapper.selectBisHiddConsultByGuid(guid);
    }

    @Override
    public int insertBisHiddConsult(BisHiddConsult bisHiddConsult) {
        return bisHiddConsultMapper.insertBisHiddConsult(bisHiddConsult);
    }

    @Override
    public int updateBisHiddConsult(BisHiddConsult bisHiddConsult) {
        return bisHiddConsultMapper.updateBisHiddConsult(bisHiddConsult);
    }

    @Override
    public int deleteBisHiddConsultByGuids(String[] guids) {
        return bisHiddConsultMapper.deleteBisHiddConsultByGuids(guids);
    }
}
